Fork of [simon-r/dr14_t.meter](https://github.com/simon-r/dr14_t.meter) with applied pull requests and minor fixes.

### Introduction to DR14 T.meter ###

DR14 T.meter is a free and open source command line tool for computing the Dynamic Range of your music according to the procedure used in the off-line meter released by the Pleasurize Music Foundation. [Link to the procedure's definition in PDF article](http://www.dynamicrange.de/sites/default/files/Measuring%20DR%20ENv3.pdf)

This tool is very useful to measure how is loud your music and for understanding that a good quality album always has also a good dynamic, and it's also useful for understanding the effects of the so called loudness war.

Dr14 t.meter is released under the terms of the  GNU GPLv3 license and  is intended for the Linux users that can not use the Windows application released by the Pleasurize Music Foundation or the plugin for Foobar2000.

I've largely tested this application and it has always returned results identical to those of the official off-line meter. 


For more info visit: https://github.com/pe7ro/p7_dr14tmeter
